pub trait MultiValueLength {
// Required method
fn multi_value_len(&self) -> usize;
}Expand description
Indicates that a multi-value has a countable number of single items contained.
This applies to single items as well, which have a multi value length of 1.
Required Methods
Sourcefn multi_value_len(&self) -> usize
fn multi_value_len(&self) -> usize
The number of single items contained a multi-value.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".